@@ -29,14 +29,8 @@ initialize.net <- function(x, param, init, control, s) {
 
 
     # Network Simulation ------------------------------------------------------
-    if (class(x$fit) == "network") {
-      nw <- simulate(x$formation,
-                     basis = x$fit,
-                     coef = x$coef.form.crude,
-                     constraints = x$constraints)
-    } else {
-      nw <- simulate(x$fit, control = control$set.control.ergm)
-    }
+    nw <- simulate(x$fit, basis = x$fit$newnetwork,
+                   control = control$set.control.ergm)
     modes <- ifelse(nw %n% "bipartite", 2, 1)
     if (control$depend == TRUE) {
       if (class(x$fit) == "stergm") {
@@ -58,26 +52,24 @@ initialize.net <- function(x, param, init, control, s) {
 
     # Initialization ----------------------------------------------------------
 
-    ## Infection Status and Time Modules
-    dat <- init_status.net(dat)
-
-
     ## Initialize persistent IDs
     if (control$use.pids == TRUE) {
       dat$nw <- init_pids(dat$nw, dat$control$pid.prefix)
     }
 
-
     ## Pull network val to attr
     form <- get_nwparam(dat)$formation
-    fterms <- get_formula_terms(form)
+    fterms <- get_formula_term_attr(form, nw)
     dat <- copy_toall_attr(dat, at = 1, fterms)
 
-
     ## Store current proportions of attr
+    dat$temp$fterms <- fterms
     dat$temp$t1.tab <- get_attr_prop(dat$nw, fterms)
 
 
+    ## Infection Status and Time Modules
+    dat <- init_status.net(dat)
+
     ## Get initial prevalence
     dat <- get_prev.net(dat, at = 1)
   } else {
@@ -143,8 +135,7 @@ init_status.net <- function(dat) {
 
   status.vector <- dat$init$status.vector
   num <- network.size(dat$nw)
-  form <- get_nwparam(dat)$form
-  statOnNw <- "status" %in% get_formula_terms(form)
+  statOnNw <- "status" %in% dat$temp$fterms
 
   modes <- dat$param$modes
   if (modes == 1) {
@@ -243,7 +234,7 @@ init_status.net <- function(dat) {
 #' first mode in a bipartite network, the IDs for the second mode shift
 #' upward. Persistent IDs allow for an analysis of disease transmission
 #' chains for these simulations. These IDs are also invoked in the
-#' \code{\link{births.net}} module when the persistent IDs of incoming nodes
+#' \code{\link{arrivals.net}} module when the persistent IDs of incoming nodes
 #' must be set.
 #'
 #' @export
