@@ -127,6 +127,10 @@ netsim <- function(x, param, init, control) {
   ncores <- ifelse(nsims == 1, 1, min(parallel::detectCores(), control$ncores))
   control$ncores <- ncores
 
+  if (is.null(control$depend)) {
+    control$depend <- FALSE
+  }
+
   if (ncores == 1) {
     for (s in 1:control$nsims) {
 
