@@ -32,7 +32,7 @@ test_that("SI, 1G, CL: varying inf.prob and act.rate", {
 
 test_that("SI, 1G, OP: varying inf.prob", {
   param <- param.dcm(inf.prob = seq(0.1, 0.5, 0.05),
-                     act.rate = 0.25, b.rate = 1/100,
+                     act.rate = 0.25, a.rate = 1/100,
                      ds.rate = 1/100, di.rate = 1/90)
   init <- init.dcm(s.num = 500, i.num = 1)
   control <- control.dcm(type = "SI", nsteps = 10, verbose = FALSE)
@@ -44,7 +44,7 @@ test_that("SI, 1G, OP: varying inf.prob", {
 test_that("SI, 2G, OP: varying inf.prob", {
   param <- param.dcm(inf.prob = seq(0.1, 0.5, 0.05),
                      act.rate = 0.25, inf.prob.g2 = 0.1, balance = "g1",
-                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     a.rate = 1/100, a.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.dcm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
   control <- control.dcm(type = "SI", nsteps = 10, verbose = FALSE)
@@ -66,7 +66,7 @@ test_that("SIR, 1G, CL: varying inf.prob", {
 
 test_that("SIR, 1G, OP: 1 run", {
   param <- param.dcm(inf.prob = 0.2,
-                     act.rate = 2, rec.rate = 1/50, b.rate = 1/100,
+                     act.rate = 2, rec.rate = 1/50, a.rate = 1/100,
                      ds.rate = 1/100, di.rate = 1/90, dr.rate = 1/100)
   init <- init.dcm(s.num = 500, i.num = 1, r.num = 0)
   control <- control.dcm(type = "SIR", nsteps = 10, verbose = FALSE)
@@ -78,7 +78,7 @@ test_that("SIR, 2G, OP: varying inf.prob", {
   param <- param.dcm(inf.prob = seq(0.1, 0.5, 0.05), inf.prob.g2 = 0.1,
                      act.rate = 1, balance = "g1",
                      rec.rate = 1/50, rec.rate.g2 = 1/50,
-                     b.rate = 1/100, b.rate.g2 = NA,
+                     a.rate = 1/100, a.rate.g2 = NA,
                      ds.rate = 1/100, ds.rate.g2 = 1/100,
                      di.rate = 1/90, di.rate.g2 = 1/90,
                      dr.rate = 1/100, dr.rate.g2 = 1/100)
@@ -116,7 +116,7 @@ test_that("SIS, 2G, CL: varying inf.prob", {
 test_that("SIS, 1G, OP: 1 run", {
   param <- param.dcm(inf.prob = 0.2,
                      act.rate = 0.5, rec.rate = 1/50,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.dcm(s.num = 500, i.num = 1)
   control <- control.dcm(type = "SIS", nsteps = 10, verbose = FALSE)
   x <- dcm(param, init, control)
@@ -141,12 +141,12 @@ test_that("si.flow correct for closed SI model, RK4 method", {
 
 test_that("si.flow correct for closed SI model, RK4 method", {
   param <- param.dcm(inf.prob = 0.2, act.rate = 3.4,
-                     b.rate = 0.02, ds.rate = 0.01, di.rate = 0.01)
+                     a.rate = 0.02, ds.rate = 0.01, di.rate = 0.01)
   init <- init.dcm(s.num = 28650, i.num = 100)
   control <- control.dcm(type = "SI", nsteps = 2)
   mod <- dcm(param, init, control)
   df <- as.data.frame(mod)
-  expect_equal(df$num[2], df$num[1] + df$b.flow[1] - df$ds.flow[1] - df$di.flow[1])
+  expect_equal(df$num[2], df$num[1] + df$a.flow[1] - df$ds.flow[1] - df$di.flow[1])
   expect_equal(df$i.num[2], df$i.num[1] + df$si.flow[1] - df$di.flow[1])
   expect_equal(df$si.flow[1], 96.06876, tol = 0.0001)
 })
@@ -165,12 +165,12 @@ test_that("si.flow correct for closed SI model, Euler method", {
 
 test_that("si.flow correct for closed SI model, Euler method", {
   param <- param.dcm(inf.prob = 0.2, act.rate = 3.4,
-                     b.rate = 0.02, ds.rate = 0.01, di.rate = 0.01)
+                     a.rate = 0.02, ds.rate = 0.01, di.rate = 0.01)
   init <- init.dcm(s.num = 28650, i.num = 100)
   control <- control.dcm(type = "SI", nsteps = 2, odemethod = "euler")
   mod <- dcm(param, init, control)
   df <- as.data.frame(mod)
-  expect_equal(df$num[2], df$num[1] + df$b.flow[1] - df$ds.flow[1] - df$di.flow[1])
+  expect_equal(df$num[2], df$num[1] + df$a.flow[1] - df$ds.flow[1] - df$di.flow[1])
   expect_equal(df$i.num[2], df$i.num[1] + df$si.flow[1] - df$di.flow[1])
   expect_equal(df$si.flow[1], 67.76348, tol = 0.0001)
 })
